@@ -1,9 +1,14 @@
 """Information about core Odoo addons."""
 
+import sys
 from functools import lru_cache
-from importlib.resources import open_text
 from typing import Set
 
+if sys.version_info >= (3, 7):
+    from importlib.resources import open_text
+else:
+    from importlib_resources import open_text
+
 from ..odoo_series import OdooEdition, OdooSeries
 
 __all__ = [
