@@ -1,10 +1,20 @@
+"""Odoo series and editions."""
 from enum import Enum
 from typing import Optional, Set
 
 from .addons_set import AddonsSet
 
+__all__ = [
+    "OdooSeries",
+    "OdooEdition",
+    "detect_from_addon_version",
+    "detect_from_addons_set",
+]
+
 
 class OdooSeries(str, Enum):
+    """Enum that represents an Odoo Series (also known as Version)."""
+
     v8_0 = "8.0"
     v9_0 = "9.0"
     v10_0 = "10.0"
@@ -17,11 +27,17 @@ class OdooSeries(str, Enum):
 
 
 class OdooEdition(str, Enum):
+    """Enum that represents an Odoo Edition."""
+
     CE = "c"
     EE = "e"
 
 
 def detect_from_addon_version(version: str) -> Optional[OdooSeries]:
+    """Detect the Odoo Series from an addon version.
+
+    Returns ``None`` if the version is not recognized.
+    """
     parts = version.split(".")
     if len(parts) < 5:
         return None
